from machine import Pin, I2C, ADC
import time
import json
import uasyncio as asyncio

from machine import Pin
import kidbright as kb
import network
from umqtt.robust import MQTTClient
from config import (
    WIFI_SSID, WIFI_PASS,
    MQTT_BROKER, MQTT_USER, MQTT_PASS,
    MQTT_TOPIC, MQTT_TOPIC_STATUS
)


led_wifi = Pin(2, Pin.OUT)
led_wifi.value(1)  # turn the red led off
led_iot = Pin(12, Pin.OUT)
led_iot.value(1)   # turn the green led off

wlan = network.WLAN(network.STA_IF)
wlan.active(True)
wlan.connect(WIFI_SSID, WIFI_PASS)
while not wlan.isconnected():
    time.sleep(0.5)
led_wifi.value(0)  # turn the red led on


mqtt = MQTTClient(client_id="",
                  server=MQTT_BROKER,
                  user=MQTT_USER,
                  password=MQTT_PASS)
mqtt.connect()

led_iot.value(0)   # turn the green led on

sm_sensor = ADC(Pin(32))
sm_sensor.atten(ADC.ATTN_11DB)

def percentage_sm():
    sm_value = sm_sensor.read()
    return (sm_value / 4095) * 100    

async def task_status():
    while True:
        led_wifi.value(0)
        await asyncio.sleep(0.1)
        led_wifi.value(1)
        await asyncio.sleep(0.9)
        

async def task_alive():
    while True:
        mqtt.publish(MQTT_TOPIC_STATUS, "Alive")
        await asyncio.sleep(21)

async def task_sensors():
    while True:
        sm = percentage_sm()
        data = {
            'sm': sm,
            'light': kb.light(),
            'lat': 13.84,
            'lon': 100.57
        }
        
        mqtt.publish(MQTT_TOPIC, json.dumps(data))
        
        await asyncio.sleep(3600)


if __name__ == "__main__":
    kb.init()
        
    asyncio.create_task(task_status())
    asyncio.create_task(task_sensors())
    asyncio.create_task(task_alive())

    asyncio.run_until_complete()